@@ -8,18 +8,22 @@
 #' @param votes_election1 data.frame (or matrix) of order IxJ (likely of final order IxJ-1
 #'                        in `regular` and `raw` scenarios) with the votes gained by the *J*
 #'                        political options competing on election 1 (or origin) in the *I*
-#'                        territorial units considered.
+#'                        territorial units considered. In general, the row marginals 
+#'                        of the *I* tables.
 #'
 #' @param votes_election2 data.frame (or matrix) of order IxK (likely of final order IxK-1
 #'                        in `regular` and `raw` scenarios) with the votes gained by
 #'                        the *K* political options competing on election 2 (or destination)
-#'                        in the *I* territorial units considered.
+#'                        in the *I* territorial units considered. In general, the column marginals 
+#'                        of the *I* tables.
 #'
 #' @param new_and_exit_voters A character string indicating the level of information available
 #'                            regarding new entries and exits of the election censuses between the
 #'                            two elections. This argument captures the different options discussed
 #'                            on Section 3 of Romero et al. (2020). This argument admits five values:
-#'                            `regular`, `raw`, `simultaneous`, `full` and `gold`. Default, `regular`.
+#'                            `raw`, `regular`, `simultaneous`, `full` and `gold`. Default, `raw`.
+#'                            The argument `simultaneous` should be used in a typical ecological inference 
+#'                            problem.
 #'
 #' @param structural_zeros Default, NULL. A list of vectors of length two, indicating the election options
 #'                         for which no transfer of votes are allowed between election 1 and election 2.
@@ -33,15 +37,15 @@
 #'                 local unit between two consecutive iterations. By default, 1000.
 #'
 #' @param uniform A TRUE/FALSE value that indicates if census exits affects all the electoral options in a
-#'                (relatively) similar fashion in each voting unit: equation (13) of Pavia and Romero (2021).
+#'                (relatively) similar fashion in each voting unit: equation (13) of Pavia and Romero (2021a).
 #'                Default, TRUE.
 #'
 #' @param distance.local A string argument that indicates whether the second step of the lphom_local algorithm
-#'                       should be performed in order to resolve potential indeterminacies of local solutions.
+#'                       should be performed to solve potential indeterminacies of local solutions.
 #'                       Default, `"abs"`.
-#'                       If `distance.local = "abs"` lphom_local selects in its the second step the matrix
+#'                       If `distance.local = "abs"` lphom_local selects in its second step the matrix
 #'                       closer to the temporary global solution under L_1 norm, among the first step compatible matrices.
-#'                       If `distance.local = "abs"` lphom_local selects in its the second step the matrix
+#'                       If `distance.local = "max"` lphom_local selects in its second step the matrix
 #'                       closer to the temporary global solution under L_Inf norm, among the first step compatible matrices.
 #'                       If `distance.local = "none"`, the second step of lphom_local is not performed.
 #'
@@ -58,27 +62,31 @@
 #'
 #' @details Description of the `new_and_exit_voters` argument in more detail.
 #' \itemize{
-#'  \item{`regular`: }{The default value. This argument accounts for the most plausible scenario.
-#'                    A scenario with two elections elapsed at least some months.
-#'                    In this scenario, (i) the column *J* of  `votes_election1` corresponds to
-#'                    new young electors who have the right to vote for the first time and (ii)
-#'                    net exits (basically a consequence of mortality), and eventually net entries,
-#'                    are computed according equation (7) of Romero et al. (2020), and (iii) we
-#'                    assume net exits affect equally all the first *J-1* options of election 1,
-#'                     hence (8) and (9) constraints of Romero et al. (2020) are imposed.}
-#'  \item{`raw`: }{This value accounts for a scenario with two elections where only the raw
-#'                 election data recorded in the *I* territorial units, in which the area
-#'                 under study is divided, are available. In this scenario, net exits
-#'                 (basically deaths) and net entries (basically new young voters) are estimated
-#'                 according to equation (7) of Romero et al. (2020). Constraints defined by
-#'                 equations (8) and (9) of Romero et al. (2020) are imposed. In this scenario,
-#'                 when net exits and/or net entries are negligible (such as between the first- and
-#'                 second-round of French Presidential elections), they are omitted in the outputs.}
-#'  \item{`simultaneous`: }{This value accounts for either a scenario with two simultaneous elections
-#'                 or a classical ecological inference problem. In this scenario, the sum by rows
-#'                 of `votes_election1` and `votes_election2` must coincide. Constraints
-#'                 defined by equations (8) and (9) of Romero et al. (2020) are not included
-#'                 in the model.}
+#'  \item{`raw`: }{The default value. This argument accounts for the most plausible scenario when
+#'                 estimating vote transfer matrices: A scenario with two elections elapsed at least some
+#'                 months where only the raw election data recorded in the *I* territorial units, 
+#'                 in which the area under study is divided, are available. 
+#'                 In this scenario, net exits (basically deaths) and net entries (basically 
+#'                 new young voters) are estimated according to equation (7) of Romero et al. (2020). 
+#'                 Constraints defined by equations (8) and (9) of Romero et al. (2020) and (13) of Pavia
+#'                 and Romero (2021a) are imposed. 
+#'                 In this scenario, when net exits and/or net entries are negligible (such as between 
+#'                 the first- and second-round of French Presidential elections), they are omitted in 
+#'                 the outputs.}
+#'  \item{`regular`: }{ For estimating vote transfer matrices, this value accounts for a scenario with 
+#'                 two elections elapsed at least some months where (i) the column *J* of `votes_election1` 
+#'                 corresponds to new young electors who have the right to vote for the first time and (ii)
+#'                 net exits (basically a consequence of mortality), and eventually net entries,
+#'                 are computed according equation (7) of Romero et al. (2020), and (iii) within each unit 
+#'                 it is assummed that net exits affect equally all the first *J-1* options 
+#'                 of election 1. Hence when `uniform = TRUE` equation (13) of Pavia and 
+#'                 Romero (2021a) is applied. Constraints (8) and (9) of Romero et al. (2020)
+#'                 are imposed to start the process.}
+#'  \item{`simultaneous`: }{ This is the value to be used in a classical ecological inference problems, 
+#'                such as for racial voting, and in a scenario with two simultaneous elections. 
+#'                In this scenario, the sum by rows of `votes_election1` and `votes_election2` must coincide. 
+#'                Constraints defined by equations (8) and (9) of Romero et al. (2020) and (13) of Pavia and 
+#'                Romero (2021a) are not included in the model.}
 #'  \item{`full`: }{This value accounts for a scenario with two elections elapsed at least some
 #'                months, where: (i) the column *J-1* of votes_election1 totals new young
 #'                electors that have the right to vote for the first time; (ii) the column *J*
@@ -100,13 +108,13 @@
 #'  \item{VTM}{ A matrix of order JxK with the estimated percentages of row-standardized vote transitions from election 1 to election 2.}
 #'  \item{VTM.votes}{ A matrix of order JxK with the estimated vote transitions from election 1 to election 2.}
 #'  \item{OTM}{ A matrix of order KxJ with the estimated percentages of the origin of the votes obtained for the different options of election 2.}
-#'  \item{HETe}{ The estimated heterogeneity index as defined in equation (15) of Pavia and Romero (2021).}
+#'  \item{HETe}{ The estimated heterogeneity index as defined in equation (15) of Pavia and Romero (2021a).}
 #'  \item{VTM.complete}{ A matrix of order J'xK' with the estimated proportions of row-standardized vote transitions from election 1 to election 2, including in `regular` and `raw` scenarios the row and the column corresponding to net_entries and net_exits even when they are really small, less than 1% in all units.}
 #'  \item{VTM.complete.votes}{ A matrix of order J'xK' with the estimated vote transitions from election 1 to election 2, including in `regular` and `raw` scenarios the row and the column corresponding to net_entries and net_exits even when they are really small, less than 1% in all units.}
 #'  \item{VTM.prop.units}{ An array of order J'xK'xI with the estimated proportions of vote transitions from election 1 to election 2 attained for each unit in the solution.}
 #'  \item{VTM.votes.units}{ An array of order J'xK'xI with the estimated matrix of vote transitions from election 1 to election 2 attained for for each unit in the solution.}
-#'  \item{VTM.complete.last.iter}{ A matrix of order J'xK' with the estimated proportions of vote transitions from election 1 to election 2, including in `regular` and `raw` scenarios the row and the column corresponding to net_entries and net_exits even when they are really small, less than 1% in all units, corresponding to the final iteration}
-#'  \item{VTM.sequence}{ Array of order J'xK'x(iter+1) (where `iter` is the efective number of iterations performed) of the intermediated estimated matrices corresponding to each iteration.}
+#'  \item{VTM.complete.last.iter}{ A matrix of order J'xK' with the estimated proportions of vote transitions from election 1 to election 2, including in `regular` and `raw` scenarios the row and the column corresponding to net_entries and net_exits even when they are really small, less than 1% in all units, corresponding to the final iteration.}
+#'  \item{VTM.sequence}{ Array of order J'xK'x(iter+1) (where `iter` is the efective number of iterations performed) of the intermediate estimated matrices corresponding to each iteration.}
 #'  \item{HETe.sequence}{ Numeric vector of length `iter+1` with the `HETe` coefficients corresponding to the matrices in `VTM.sequence`.}
 #'  \item{VTM.prop.units.last.iter}{ An array of order J'xK'xI with the estimated proportions of vote transitions from election 1 to election 2 attained for each unit in the final iteration.}
 #'  \item{VTM.votes.units.last.iter}{ An array of order J'xK'xI with the estimated matrix of vote transitions from election 1 to election 2 attained for each unit in the final iteration.}
@@ -115,18 +123,20 @@
 #'  \item{iter.units}{ A matrix of order Ix(iter+1) with the number of iteration corresponding to the solution selected for each unit
 #'                    in each iteration.}
 #'  \item{errors}{ A vector of length I with the minimal error observed in the sequence for each unit. It corresponds to
-#'                the error associated with the solution linked with `VTM_units.iter`.}
+#'                the unit-error associated with the solution linked with either `VTM.prop.units` or `VTM.votes.units`.}
 #'  \item{inputs}{ A list containing all the objects with the values used as arguments by the function.}
 #'  \item{origin}{ A matrix with the final data used as votes of the origin election after taking into account the level of information available regarding to new entries and exits of the election censuses between the two elections.}
 #'  \item{destination}{ A matrix with the final data used as votes of the origin election after taking into account the level of information available regarding to new entries and exits of the election censuses between the two elections.}
-#'  \item{EHet}{ A matrix of order IxK measuring in each spatial unit a distance to the homogeneity hypothesis, that is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results with the solution in each territorial unit for each option of election two.}
+#'  \item{EHet}{ A matrix of order IxK measuring in each spatial unit a distance to the homogeneity hypothesis, that is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results with the solution in each territorial unit for each option of election 2.}
 #'  \item{solution_init}{ A list with the main outputs produced by **lphom()**.}
 #'  \itemize{
 #'  \item{`VTM_init`:}{ A matrix of order JxK with the estimated percentages of vote transitions from election 1 to election 2 initially obtained by **lphom()**.}
+#'  \item{`VTM.votes_init`:}{ A matrix of order JxK with the estimated vote transitions from election 1 to election 2 initially obtained by **lphom()**.}
 #'  \item{`OTM_init`:}{ A matrix of order KxJ with the estimated percentages of the origin of the votes obtained for the different options of election 2 initially obtained by **lphom()**.}
 #'  \item{`HETe_init`:}{ The estimated heterogeneity index defined in equation (10) of Romero et al. (2020). }
-#'  \item{`EHet_init`:}{ A matrix of order IxK measuring in each spatial unit the distance to the homogeneity hypothesis, that is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results, using the **lphom()** solution, in each territorial unit for each option of election two.}
+#'  \item{`EHet_init`:}{ A matrix of order IxK measuring in each spatial unit the distance to the homogeneity hypothesis, that is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results, using the **lphom()** solution, in each territorial unit for each option of election 2.}
 #'  \item{`VTM.complete_init`:}{ A matrix of order J'xK' with the estimated proportions of vote transitions from election 1 to election 2 initially obtained by **lphom()**, including in `regular` and `raw` scenarios the row and the column corresponding to net_entries and net_exits even when they are really small, less than 1% in all units.}
+#'  \item{`VTM.complete.votes_init`:}{ A matrix of order J'xK' with the estimated vote transitions from election 1 to election 2 initially obtained by **lphom()**, including in `regular` and `raw` scenarios the row and the column corresponding to net_entries and net_exits even when they are really small, less than 1% in all units.}
 #' }
 #'
 #' @export
@@ -135,25 +145,25 @@
 #' @seealso \code{\link{lphom}} \code{\link{tslphom}} \code{\link{nslphom}}
 #'
 #' @examples
-#' mt.lns <- lclphom(France2017P[, 1:8] , France2017P[, 9:12], new_and_exit_voters= "raw")
-#' mt.lns$VTM
-#' mt.lns$HETe
-#' mt.lns$solution_init$HETe_init
+#' mt.lc <- lclphom(France2017P[, 1:8] , France2017P[, 9:12], new_and_exit_voters= "raw")
+#' mt.lc$VTM
+#' mt.lc$HETe
+#' mt.lc$solution_init$HETe_init
 #'
 #' @importFrom Rsymphony Rsymphony_solve_LP
 #' @importFrom lpSolve lp
 #'
 
 lclphom <- function(votes_election1,
-                     votes_election2,
-                     new_and_exit_voters = c("regular", "raw", "simultaneous", "full", "gold"),
-                     structural_zeros = NULL,
-                     iter.max = 1000,
-                     uniform = TRUE,
-                     distance.local = c("abs", "max", "none"),
-                     counts = FALSE,
-                     solver = "lp_solve",
-                     verbose = FALSE ){
+                    votes_election2,
+                    new_and_exit_voters = c("raw", "regular", "simultaneous", "full", "gold"),
+                    structural_zeros = NULL,
+                    iter.max = 1000,
+                    uniform = TRUE,
+                    distance.local = c("abs", "max", "none"),
+                    counts = FALSE,
+                    solver = "lp_solve",
+                    verbose = FALSE ){
 
   if (iter.max < 0 | iter.max%%1 > 0)
     stop('iter.max must be a positive integer')
@@ -217,6 +227,8 @@ lclphom <- function(votes_election1,
   if (iter != iter.max) iter <- iter - 1L
   iter.units <- iter.units[, 1L:(iter + 1L)]
   VTM.sequence <- VTM.sequence[, , 1L:(iter + 1L)]
+  dimnames(iter.units) <- list(rownames(lphom_inic$origin),
+                            paste0("iter = ", 0L:iter))
   dimnames(VTM.sequence) <- c(dimnames(lphom_inic$VTM.complete),
                               list(paste0("iter = ", 0L:iter)))
   HETe.sequence <- HETe.sequence[1L:(iter + 1L)]
@@ -261,6 +273,14 @@ lclphom <- function(votes_election1,
               "distance.local" = distance.local)
   inic <- lphom_inic[c(1L:6L, 10L)]
   names(inic) <- paste0(names(inic), "_init")
+  
+  # Caso de filas o columnas con cero votos
+  filas0 <- which(rowSums(VTM_votos) == 0)
+  colum0 <- which(colSums(VTM_votos) == 0)
+  VTM[filas0, ] <- 0
+  VTM.complete[filas0, ] <- 0
+  OTM[colum0, ] <- 0
+  
   output <- list("VTM" = VTM, "VTM.votes" = VTM.votes, "OTM" = OTM, "HETe" = HETe,
               "VTM.complete" = VTM.complete, "VTM.complete.votes" = VTM_votos,
               "VTM.prop.units" = VTM_units, "VTM.votes.units" = votos_units,
@@ -270,6 +290,6 @@ lclphom <- function(votes_election1,
               "iter" = iter, "iter.units" = iter.units, "errors" = errors, "EHet" = EHet,
               "inputs" = inputs, "origin" = lphom_inic$origin,
               "destination" = lphom_inic$destination, "solution_init" = inic)
-  class(output) <- "lclphom"
+  class(output) <- c("lclphom", "ei_lp", "lphom")
   return(output)
 }
