@@ -6,16 +6,16 @@
 #' @author Rafael Romero \email{rromero@@eio.upv.es}
 #' @references Pavia, JM and Romero, R (2021). Symmetry estimating R×C vote transfer matrices from aggregate data, mimeo.
 #'
-#' @param votes_election1 data.frame (or matrix) of order IxJ with the votes gained by the *J*
-#'                        political options competing on election 1 (or origin) in the *I*
-#'                        territorial units considered. In general, the counts to be initially
-#'                        mapped to columns. The sum by rows of `votes_election1` and
+#' @param votes_election1 data.frame (or matrix) of order IxJ with the counts to be initially
+#'                        mapped to rows. When estimating vote transfer matrices, the votes gained by 
+#'                        the *J* political options competing on election 1 (or origin) in the *I*
+#'                        territorial units considered.  The sum by rows of `votes_election1` and
 #'                        `votes_election2` must coincide.
 #'
-#' @param votes_election2 data.frame (or matrix) of order IxK with the votes gained by
-#'                        the *K* political options competing on election 2 (or destination)
-#'                        in the *I* territorial units considered. In general, the counts to be
-#'                        initially mapped to columns. The sum by rows of `votes_election1` and
+#' @param votes_election2 data.frame (or matrix) of order IxK with the counts to be initially mapped 
+#'                        to columns. When estimating vote transfer matrices, the votes gained by
+#'                        the *K* political options competing on election 2 (or destination) in the *I* 
+#'                        territorial units considered. In general, The sum by rows of `votes_election1` and
 #'                        `votes_election2` must coincide.
 #'
 #' @param counts A TRUE/FALSE value that indicates whether the linked LP solution of votes must be approximate
@@ -100,8 +100,10 @@ lphom_dual <- function(votes_election1,
     dimnames(VTM1.weighted) <- dimnames(VTM1) <- dimnames(lphom.object.12$VTM)
   dimnames(VTM2.weighted) <- dimnames(VTM2) <- dimnames(lphom.object.12$OTM)
 
-  return(list("VTM.votes.w" = VTM.votos.weigthed, "VTM.votes.a" = VTM.votos, "HETe.w" = HETe.w,
+  output <- list("VTM.votes.w" = VTM.votos.weigthed, "VTM.votes.a" = VTM.votos, "HETe.w" = HETe.w,
               "HETe.a" = HETe.a, "VTM12.w" = VTM1.weighted, "VTM21.w" = VTM2.weighted,
               "VTM12.a" = VTM1, "VTM21.a" = VTM2, "lphom.object.12" = lphom.object.12,
-              "lphom.object.21" = lphom.object.21, "inputs" = inputs))
+              "lphom.object.21" = lphom.object.21, "inputs" = inputs)
+  class(output) <- c("lphom_dual", "ei_dual", "lphom")
+  return(output)
 }
