@@ -4,18 +4,18 @@
 #'
 #' @author Jose M. Pavia, \email{pavia@@uv.es}
 #' @author Rafael Romero \email{rromero@@eio.upv.es}
-#' @references Pavia, JM and Romero, R (2021). Symmetry estimating R×C vote transfer matrices from aggregate data, mimeo.
+#' @references Pavia, JM and Romero, R (2021). Symmetry estimating RxC vote transfer matrices from aggregate data, mimeo.
 #'
-#' @param votes_election1 data.frame (or matrix) of order IxJ with the votes gained by the *J*
-#'                        political options competing on election 1 (or origin) in the *I*
-#'                        territorial units considered. In general, the counts to be initially
-#'                        mapped to columns. The sum by rows of `votes_election1` and
+#' @param votes_election1 data.frame (or matrix) of order IxJ with the counts to be initially
+#'                        mapped to rows. When estimating vote transfer matrices, the votes gained by 
+#'                        the *J* political options competing on election 1 (or origin) in the *I*
+#'                        territorial units considered.  The sum by rows of `votes_election1` and
 #'                        `votes_election2` must coincide.
 #'
-#' @param votes_election2 data.frame (or matrix) of order IxK with the votes gained by
-#'                        the *K* political options competing on election 2 (or destination)
-#'                        in the *I* territorial units considered. In general, the counts to be
-#'                        initially mapped to columns. The sum by rows of `votes_election1` and
+#' @param votes_election2 data.frame (or matrix) of order IxK with the counts to be initially mapped 
+#'                        to columns. When estimating vote transfer matrices, the votes gained by
+#'                        the *K* political options competing on election 2 (or destination) in the *I* 
+#'                        territorial units considered. In general, The sum by rows of `votes_election1` and
 #'                        `votes_election2` must coincide.
 #'
 #' @param iter.max Maximum number of iterations to be performed. The process ends independently when either
@@ -39,7 +39,7 @@
 #'
 #' @param tol Maximum deviation allowed between two consecutive iterations. The process ends when the maximum
 #'            variation between the estimated cross-distributions of votes between two consecutive
-#'            iterations is less than `tol` or the maximum number of iterations has been reached. By default, 0.001.
+#'            iterations is less than `tol` or the maximum number of iterations, `iter.max`, has been reached. By default, 0.001.
 #'
 #' @return
 #' A list with the following components
@@ -50,6 +50,8 @@
 #'    \item{VTM.votes.units}{ An array of order JxKxI with the estimated matrix of cross-distributions of votes of elections 1 and 2 attained for each unit in iteration of the solution.}
 #'    \item{iter}{ The real final number of iterations performed before ending the process.}
 #'    \item{iter.min}{ Number of the iteration associated to the selected `VTM.votes` solution.}
+#'    \item{EHet12}{ A matrix of order IxK measuring in each unit a distance to the homogeneity hypothesis. That is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results in each territorial unit for each option of election two. The matrix Eik.}
+#'    \item{EHet21}{ A matrix of order IxJ measuring in each unit a distance to the homogeneity hypothesis. That is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results in each territorial unit for each option of election one. The matrix Eij.}
 #'    \item{inputs}{ A list containing all the objects with the values used as arguments by the function.}
 #'    \item{solution_init}{ A list with the main outputs produced by **lphom_joint()**.}
 #'
@@ -63,7 +65,7 @@
 #' x <- France2017P[, 1:8]
 #' y <- France2017P[, 9:12]
 #' y[,1] <- y[,1]  - (rowSums(y) - rowSums(x))
-#' mt <- nslphom_joint(x, y)
+#' mt <- nslphom_joint(x, y, iter.max = 3)
 #' mt$VTM.votes
 #' mt$HETe
 #
@@ -142,6 +144,9 @@ nslphom_joint <- function(votes_election1,
   dimnames(VTM.votes_units) <- c(dimnames(lphom_inic$VTM.votes), list(rownames(votes_election1)))
   dimnames(VTM.votes.sequence) <- c(dimnames(VTM.votes), list(c(0:iter)))
 
+  eik <- votes_election2 - as.matrix(votes_election1) %*% VTM1
+  eij <- votes_election1 - as.matrix(votes_election2) %*% VTM2
+  
   inic <- lphom_inic[1:6]
   names(inic) <- paste0(names(inic), "_init")
 
@@ -150,8 +155,10 @@ nslphom_joint <- function(votes_election1,
   inputs$min.first <- min.first
   inputs$tol <- tol
 
-  return(list("VTM.votes" = VTM.votes, "HETe" = HETe.iter, "VTM12" =VTM1, "VTM21" = VTM2,
+  output <- list("VTM.votes" = VTM.votes, "HETe" = HETe.iter, "VTM12" =VTM1, "VTM21" = VTM2,
               "HETe.sequence" = HETe.sequence, "VTM.votes.sequence" = VTM.votes.sequence,
               "VTM.votes.units" = VTM.votes_units, "iter" = iter, "iter.min" = iter.min,
-              "inputs" = inputs, "solution_init" = inic))
+              "EHet.12" = eik, "EHet.21" = eij, "inputs" = inputs, "solution_init" = inic)
+  class(output) <- c("nslphom_joint", "ei_joint", "lphom")
+  return(output)
 }
