@@ -9,18 +9,22 @@
 #' @param votes_election1 data.frame (or matrix) of order IxJ (likely of final order IxJ-1
 #'                        in `regular` and `raw` scenarios) with the votes gained by the *J*
 #'                        political options competing on election 1 (or origin) in the *I*
-#'                        territorial units considered.
+#'                        territorial units considered. In general, the row marginals 
+#'                        of the *I* tables.
 #'
 #' @param votes_election2 data.frame (or matrix) of order IxK (likely of final order IxK-1
 #'                        in `regular` and `raw` scenarios) with the votes gained by
 #'                        the *K* political options competing on election 2 (or destination)
-#'                        in the *I* territorial units considered.
+#'                        in the *I* territorial units considered. In general, the column marginals 
+#'                        of the *I* tables.
 #'
 #' @param new_and_exit_voters A character string indicating the level of information available
 #'                            regarding new entries and exits of the election censuses between the
 #'                            two elections. This argument captures the different options discussed
 #'                            on Section 3 of Romero et al. (2020). This argument admits five values:
-#'                            `regular`, `raw`, `simultaneous`, `full` and `gold`. Default, `regular`.
+#'                            `raw`, `regular`, `simultaneous`, `full` and `gold`. Default, `raw`.
+#'                            The argument `simultaneous` should be used in a typical ecological inference 
+#'                            problem.
 #'
 #' @param structural_zeros Default NULL. A list of vectors of length two, indicating the election options
 #'                         for which no transfer of votes are allowed between election 1 and election 2.
@@ -34,16 +38,16 @@
 #'                Default, TRUE.
 #'
 #' @param distance.local A string argument that indicates whether the second step of the lphom_local algorithm
-#'                       should be performed in order to resolve potential indeterminacies of local solutions.
+#'                       should be performed to solve potential indeterminacies of local solutions.
 #'                       Default, `"abs"`.
-#'                       If `distance.local = "abs"` lphom_local selects in its the second step the matrix
-#'                       closer to the **lphom()** solution under L_1 norm, among the first step compatible matrices.
-#'                       If `distance.local = "max"` lphom_local selects in its the second step the matrix
-#'                       closer to the **lphom()** solution under L_Inf norm, among the first step compatible matrices.
+#'                       If `distance.local = "abs"` lphom_local selects in its second step the matrix
+#'                       closer to the temporary global solution under L_1 norm, among the first step compatible matrices.
+#'                       If `distance.local = "max"` lphom_local selects in its second step the matrix
+#'                       closer to the temporary global solution under L_Inf norm, among the first step compatible matrices.
 #'                       If `distance.local = "none"`, the second step of lphom_local is not performed.
 #'
 #' @param counts A TRUE/FALSE value that indicates whether the problem is solved in integer values (counts),
-#'               in both iterations: zero (lphom) and final (including unit) solutions. If TRUE, the LP matrices
+#'               in both iterations, including iteration zero (lphom) and final (including unit) solutions. If TRUE, the LP matrices
 #'               are approximated to the closest integer solution solving the corresponding Integer Linear Program.
 #'               Default, FALSE.
 #'
@@ -56,27 +60,31 @@
 #'
 #' @details Description of the `new_and_exit_voters` argument in more detail.
 #' \itemize{
-#'  \item{`regular`: }{The default value. This argument accounts for the most plausible scenario.
-#'                    A scenario with two elections elapsed at least some months.
-#'                    In this scenario, (i) the column *J* of  `votes_election1` corresponds to
-#'                    new young electors who have the right to vote for the first time and (ii)
-#'                    net exits (basically a consequence of mortality), and eventually net entries,
-#'                    are computed according equation (7) of Romero et al. (2020), and (iii) we
-#'                    assume net exits affect equally all the first *J-1* options of election 1,
-#'                     hence (8) and (9) constraints of Romero et al. (2020) are imposed.}
-#'  \item{`raw`: }{This value accounts for a scenario with two elections where only the raw
-#'                 election data recorded in the *I* territorial units, in which the area
-#'                 under study is divided, are available. In this scenario, net exits
-#'                 (basically deaths) and net entries (basically new young voters) are estimated
-#'                 according to equation (7) of Romero et al. (2020). Constraints defined by
-#'                 equations (8) and (9) of Romero et al. (2020) are imposed. In this scenario,
-#'                 when net exits and/or net entries are negligible (such as between the first- and
-#'                 second-round of French Presidential elections), they are omitted in the outputs.}
-#'  \item{`simultaneous`: }{This value accounts for either a scenario with two simultaneous elections
-#'                 or a classical ecological inference problem. In this scenario, the sum by rows
-#'                 of `votes_election1` and `votes_election2` must coincide. Constraints
-#'                 defined by equations (8) and (9) of Romero et al. (2020) are not included
-#'                 in the model.}
+#'  \item{`raw`: }{The default value. This argument accounts for the most plausible scenario when
+#'                 estimating vote transfer matrices: A scenario with two elections elapsed at least some
+#'                 months where only the raw election data recorded in the *I* territorial units, 
+#'                 in which the area under study is divided, are available. 
+#'                 In this scenario, net exits (basically deaths) and net entries (basically 
+#'                 new young voters) are estimated according to equation (7) of Romero et al. (2020). 
+#'                 Constraints defined by equations (8) and (9) of Romero et al. (2020) and (13) of Pavia
+#'                 and Romero (2021a) are imposed. 
+#'                 In this scenario, when net exits and/or net entries are negligible (such as between 
+#'                 the first- and second-round of French Presidential elections), they are omitted in 
+#'                 the outputs.}
+#'  \item{`regular`: }{ For estimating vote transfer matrices, this value accounts for a scenario with 
+#'                 two elections elapsed at least some months where (i) the column *J* of `votes_election1` 
+#'                 corresponds to new young electors who have the right to vote for the first time and (ii)
+#'                 net exits (basically a consequence of mortality), and eventually net entries,
+#'                 are computed according equation (7) of Romero et al. (2020), and (iii) within each unit 
+#'                 it is assummed that net exits affect equally all the first *J-1* options 
+#'                 of election 1. Hence when `uniform = TRUE` equation (13) of Pavia and 
+#'                 Romero (2021a) is applied. Constraints (8) and (9) of Romero et al. (2020)
+#'                 are imposed to start the process.}
+#'  \item{`simultaneous`: }{ This is the value to be used in a classical ecological inference problems, 
+#'                such as for racial voting, and in a scenario with two simultaneous elections. 
+#'                In this scenario, the sum by rows of `votes_election1` and `votes_election2` must coincide. 
+#'                Constraints defined by equations (8) and (9) of Romero et al. (2020) and (13) of Pavia and 
+#'                Romero (2021a) are not included in the model.}
 #'  \item{`full`: }{This value accounts for a scenario with two elections elapsed at least some
 #'                months, where: (i) the column *J-1* of votes_election1 totals new young
 #'                electors that have the right to vote for the first time; (ii) the column *J*
@@ -107,14 +115,16 @@
 #'  \item{inputs}{ A list containing all the objects with the values used as arguments by the function.}
 #'  \item{origin}{ A matrix with the final data used as votes of the origin election after taking into account the level of information available regarding to new entries and exits of the election censuses between the two elections.}
 #'  \item{destination}{ A matrix with the final data used as votes of the origin election after taking into account the level of information available regarding to new entries and exits of the election censuses between the two elections.}
-#'  \item{EHet}{ A matrix of order IxK measuring in each spatial unit a distance to the homogeneity hypothesis, that is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results with the solution in each territorial unit for each option of election two.}
+#'  \item{EHet}{ A matrix of order IxK measuring in each spatial unit a distance to the homogeneity hypothesis, that is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results with the solution in each territorial unit for each option of election 2.}
 #'  \item{solution_init}{ A list with the main outputs produced by **lphom()**.}
 #'  \itemize{
 #'  \item{`VTM_init`:}{ A matrix of order JxK with the estimated percentages of vote transitions from election 1 to election 2 initially obtained by **lphom()**.}
+#'  \item{`VTM.votes_init`:}{ A matrix of order JxK with the estimated vote transitions from election 1 to election 2 initially obtained by **lphom()**.}
 #'  \item{`OTM_init`:}{ A matrix of order KxJ with the estimated percentages of the origin of the votes obtained for the different options of election 2 initially obtained by **lphom()**.}
 #'  \item{`HETe_init`:}{ The estimated heterogeneity index defined in equation (10) of Romero et al. (2020). }
-#'  \item{`EHet_init`:}{ A matrix of order IxK measuring in each spatial unit the distance to the homogeneity hypothesis, that is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results, using the **lphom()** solution, in each territorial unit for each option of election two.}
+#'  \item{`EHet_init`:}{ A matrix of order IxK measuring in each spatial unit the distance to the homogeneity hypothesis, that is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results, using the **lphom()** solution, in each territorial unit for each option of election 2.}
 #'  \item{`VTM.complete_init`:}{ A matrix of order J'xK' with the estimated proportions of vote transitions from election 1 to election 2 initially obtained by **lphom()**, including in `regular` and `raw` scenarios the row and the column corresponding to net_entries and net_exits even when they are really small, less than 1% in all units.}
+#'  \item{`VTM.complete.votes_init`:}{ A matrix of order J'xK' with the estimated vote transitions from election 1 to election 2 initially obtained by **lphom()**, including in `regular` and `raw` scenarios the row and the column corresponding to net_entries and net_exits even when they are really small, less than 1% in all units.}
 #' }
 
 #'
@@ -137,7 +147,7 @@
 #
 tslphom <- function(votes_election1,
                     votes_election2,
-                    new_and_exit_voters = c("regular", "raw", "simultaneous", "full", "gold"),
+                    new_and_exit_voters = c("raw", "regular", "simultaneous", "full", "gold"),
                     structural_zeros = NULL,
                     uniform = TRUE,
                     distance.local = c("abs", "max", "none"),
@@ -201,11 +211,19 @@ tslphom <- function(votes_election1,
   inputs <- c(lphom_inic$inputs, "uniform" = uniform, "distance.local" = distance.local)
   inic <- lphom_inic[c(1L:6L, 10L)]
   names(inic) <- paste0(names(inic), "_init")
+  
+  # Caso de filas o columnas con cero votos
+  filas0 <- which(rowSums(VTM_votos) == 0)
+  colum0 <- which(colSums(VTM_votos) == 0)
+  VTM[filas0, ] <- 0
+  VTM.complete[filas0, ] <- 0
+  OTM[colum0, ] <- 0
+
   output <- list("VTM" = VTM, "VTM.votes" = VTM.votes, "OTM" = OTM, "HETe" = HETe,
                  "VTM.complete" = VTM.complete, "VTM.complete.votes" = VTM_votos,
                  "VTM.prop.units" = VTM_units, "VTM.votes.units" = votos_units, "zeros" = zeros,
                  "inputs" = inputs, "origin" = lphom_inic$origin,
                  "destination" = lphom_inic$destination, "EHet" = EHet, "solution_init" = inic)
-  class(output) <- "tslphom"
+  class(output) <- c("tslphom", "ei_lp", "lphom")
   return(output)
 }
